clear all;
close all;


fs=192000;
het_freq=45000;
rec_dur=1;
sig_dur=rec_dur;
fc=10e3;
nbufs=2;
feedback_threshold_output=-36;
feedback_min_dur=0.1;

input_channels=0:5;
output_channels=[0:5];
playchan=0:length(output_channels)-1;

%prepare soundmex
if 1 ~= soundmexpro('init','driver','ASIO Fireface','samplerate',fs,'input',input_channels,'output',output_channels,'numbufs',nbufs);
    error(['error calling ''init''' error_loc(dbstack)]);
end
% get asio properties
[ret,fs_ff800,bufsiz]=soundmexpro('getproperties');
fs=fs_ff800;

% set record length for audio ring buffer
if 1 ~= soundmexpro( 'recbufsize', 'value', rec_dur*fs);
    error(['error calling ''loadfile''' error_loc(dbstack)]);
end

% generate check signal
[b,a]=butter(4,2*fc/fs,'high');
sig=wind(fs,0.02,filter(b,a,randn(1,round(sig_dur*fs))/10))';

% start the presentation
disp('Hit any key to start presentation!');
pause;
for cn=1:6,
    if 1 ~= soundmexpro('loadmem', ...      % command name
            'data', sig, ...              % data vector
            'track', cn-1, ...             % tracks, here 0 and 1 (one track on each channel)
            'loopcount', 1 ...              % loopcount
            );
        error(['error calling ''loadmem''' error_loc(dbstack)]);
    end

    soundmexpro('start');
    disp(['Playing channel ' num2str(cn)]);
    drawnow;
    % wait until 'mixing' has ended (playback on tracks 2 and 3)
    while  1
        [success, playing] = soundmexpro('playing');
        % check success of command
        if 1 ~= success
            soundmexpro('exit');
            error('Fatal error in loop. Aborting...');
        end
        % then check the last two tracks (NOTE: vector is 1-based!)
        if (max(playing) == 0)
            break;
        end
        pause(0.1)
    end

    % first stop soundmexpro
    if 1 ~= soundmexpro('stop');
        error('error calling stop');
    end
    pause(0.2);
    [y,fs]=wavread(['rec_' num2str(cn-1)]);
    figure(1), subplot(3,2,cn), plot(y);
%     set(gca,'ylim',[-0.3 0.3])
    level=20*log10(std(y));
    alllevels(cn)=level;
    title(['level = ' num2str(level)]);
    f=linspace(0,fs,length(y));
    spc=20*log10(abs(fft(y)));
    spc=moving_average(spc,20);
    figure(2), subplot(3,2,cn),
    plot(f,spc);
    set(gca,'xlim',[0 fs/2],'ylim',[-10 50]);
    drawnow;
end

% get xrun information
[success, xruns]=soundmexpro('xrun');
disp(['Trial stopped with ' num2str(xruns) ' XRUNs!']);

soundmexpro('exit');
